@@ -1,9 +1,9 @@
 package App::ChromeUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-19'; # DATE
+our $DATE = '2020-06-13'; # DATE
 our $DIST = 'App-ChromeUtils'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -53,6 +53,18 @@ sub unpause_chrome {
     App::BrowserUtils::_do_browser('unpause', 'chrome', @_);
 }
 
+$SPEC{chrome_has_processes} = {
+    v => 1.1,
+    summary => "Check whether Chrome has processes",
+    args => {
+        %App::BrowserUtils::args_common,
+        %App::BrowserUtils::argopt_quiet,
+    },
+};
+sub chrome_has_processes {
+    App::BrowserUtils::_do_browser('has_processes', 'chrome', @_);
+}
+
 $SPEC{chrome_is_paused} = {
     v => 1.1,
     summary => "Check whether Chrome is paused",
@@ -101,6 +113,36 @@ sub terminate_chrome {
     App::BrowserUtils::_do_browser('terminate', 'chrome', @_);
 }
 
+$SPEC{restart_chrome} = {
+    v => 1.1,
+    summary => "Restart chrome",
+    args => {
+        %App::BrowserUtils::argopt_chrome_cmd,
+        %App::BrowserUtils::argopt_quiet,
+    },
+    features => {
+        dry_run => 1,
+    },
+};
+sub restart_chrome {
+    App::BrowserUtils::restart_browsers(@_, restart_chrome=>1);
+}
+
+$SPEC{start_chrome} = {
+    v => 1.1,
+    summary => "Start chrome if not already started",
+    args => {
+        %App::BrowserUtils::argopt_chrome_cmd,
+        %App::BrowserUtils::argopt_quiet,
+    },
+    features => {
+        dry_run => 1,
+    },
+};
+sub start_chrome {
+    App::BrowserUtils::start_browsers(@_, start_chrome=>1);
+}
+
 1;
 # ABSTRACT: Utilities related to Google Chrome browser
 
@@ -116,7 +158,7 @@ App::ChromeUtils - Utilities related to Google Chrome browser
 
 =head1 VERSION
 
-This document describes version 0.006 of App::ChromeUtils (from Perl distribution App-ChromeUtils), released on 2020-04-19.
+This document describes version 0.007 of App::ChromeUtils (from Perl distribution App-ChromeUtils), released on 2020-06-13.
 
 =head1 SYNOPSIS
 
@@ -126,6 +168,8 @@ This distribution includes several utilities related to Google Chrome browser:
 
 =over
 
+=item * L<chrome-has-processes>
+
 =item * L<chrome-is-paused>
 
 =item * L<chrome-is-running>
@@ -138,6 +182,10 @@ This distribution includes several utilities related to Google Chrome browser:
 
 =item * L<ps-chrome>
 
+=item * L<restart-chrome>
+
+=item * L<start-chrome>
+
 =item * L<terminate-chrome>
 
 =item * L<unpause-chrome>
@@ -147,6 +195,42 @@ This distribution includes several utilities related to Google Chrome browser:
 =head1 FUNCTIONS
 
 
+=head2 chrome_has_processes
+
+Usage:
+
+ chrome_has_processes(%args) -> [status, msg, payload, meta]
+
+Check whether Chrome has processes.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<quiet> => I<true>
+
+=item * B<users> => I<array[unix::local_uid]>
+
+Kill browser processes that belong to certain user(s) only.
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 chrome_is_paused
 
 Usage:
@@ -238,7 +322,7 @@ A modern browser now runs complex web pages and applications. Despite browser's
 power management feature, these pages/tabs on the browser often still eat
 considerable CPU cycles even though they only run in the background. Stopping
 (kill -STOP) the browser processes is a simple and effective way to stop CPU
-eating on Unix. It can be performed whenever you are not using your browsers for
+eating on Unix. It can be performed whenever you are not using your browser for
 a little while, e.g. when you are typing on an editor or watching a movie. When
 you want to use your browser again, simply unpause it.
 
@@ -302,6 +386,100 @@ Return value:  (any)
 
 
 
+=head2 restart_chrome
+
+Usage:
+
+ restart_chrome(%args) -> [status, msg, payload, meta]
+
+Restart chrome.
+
+This function is not exported.
+
+This function supports dry-run operation.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<chrome_cmd> => I<array[str]|str> (default: "google-chrome")
+
+=item * B<quiet> => I<true>
+
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-dry_run> => I<bool>
+
+Pass -dry_run=E<gt>1 to enable simulation mode.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
+=head2 start_chrome
+
+Usage:
+
+ start_chrome(%args) -> [status, msg, payload, meta]
+
+Start chrome if not already started.
+
+This function is not exported.
+
+This function supports dry-run operation.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<chrome_cmd> => I<array[str]|str> (default: "google-chrome")
+
+=item * B<quiet> => I<true>
+
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-dry_run> => I<bool>
+
+Pass -dry_run=E<gt>1 to enable simulation mode.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 terminate_chrome
 
 Usage:
